import logging
from os import path

from ..utils.yaml import yaml_load


logger = logging.getLogger(__name__)

PACKAGE_TYPE = 'installer'


def is_installer(filename):
    # TODO: allow
    if not filename.endswith('.sh'):
        return False

    with open(filename) as fd:
        fd.readline()
        cio_copyright = fd.readline()
        # Copyright (c) 2012-2014 Continuum Analytics, Inc.

        # TODO: it would be great if the installers had a unique identifier in the header

        # Made by CAS installer
        if "CAS-INSTALLER" in cio_copyright:
            return True

        # miniconda installer
        elif "Copyright" not in cio_copyright:
            return False

        elif "Continuum Analytics, Inc." not in cio_copyright:
            return False

        return True

    return False


def inspect_package(filename, fileobj, *args, **kwarg):
    # skip #!/bin/bash
    line = fileobj.readline()
    lines = []
    while line.startswith('#'):
        if ':' in line:
            lines.append(line.strip(" #\n"))
        line = fileobj.readline()

    try:
        installer_data = yaml_load("\n".join(lines))
    finally:
        logger.error("Could not load installer info as YAML")

    summary = "Conda installer for platform %s" % installer_data.pop('PLAT')
    name = installer_data.pop('NAME')
    version = installer_data.pop('VER')

    attrs = installer_data

    package_data = {
        'name': name,
        'summary': summary,
        'license': None,
    }
    release_data = {
        'version': version,
        'description': summary,
    }
    file_data = {
        'basename': path.basename(filename),
        'attrs': attrs,
        'binstar_package_type': 'file',
    }

    return package_data, release_data, file_data



"""
Search your Anaconda repository for packages.
"""
import logging

from binstar_client.utils import get_server_api
from binstar_client.utils.pprint import pprint_packages

logger = logging.getLogger('binstar.search')


def search(args):

    aserver_api = get_server_api(args.token, args.site)

    packages = aserver_api.search(args.name, package_type=args.package_type, platform=args.platform)
    pprint_packages(packages, access=False)
    logger.info("Found %i packages" % len(packages))
    logger.info("\nRun 'anaconda show <USER/PACKAGE>' to get installation details")


def add_parser(subparsers):
    parser = subparsers.add_parser(
        'search',
        help='Search in your Anaconda repository',
        description='Search in your Anaconda repository',
        epilog=__doc__
    )
    parser.add_argument('name', nargs=1, help='Search string')
    parser.add_argument(
        '-t', '--package-type', choices=['conda', 'pypi'],
        help='only search for packages of this type'
    )
    parser.add_argument(
        '-p', '--platform',
        choices=['osx-32', 'osx-64', 'win-32', 'win-64', 'linux-32', 'linux-64',
                 'linux-armv6l', 'linux-armv7l', 'linux-ppc64le', 'noarch'],
        help='only search for packages of the chosen platform'
    )
    parser.set_defaults(main=search)
